@@ -974,6 +974,8 @@ char* readline_object_completion(const char* text, int stat)
     return NULL;
 }
 
+BOOL gDerefCompletionProgram = FALSE;
+
 char* readline_deref_completion(const char* text, int stat)
 {
     static hash_it* it;
@@ -986,12 +988,22 @@ char* readline_deref_completion(const char* text, int stat)
 
     while(it) {
         char* key = hash_loop_key(it);
+        sRef* ref = hash_loop_item(it);
         it = hash_loop_next(it);
 
         if(!strncmp(text + 1, key, wordlen-1)) {
-            char buf[1024];
-            snprintf(buf, 1024, "$%s", key);
-            return strdup(buf);
+            if(gDerefCompletionProgram && ref->mKind == kMCObject) {
+                char buf[1024];
+                snprintf(buf, 1024, "$%s->", key);
+                rl_completion_append_character= 0;
+                return strdup(buf);
+            }
+            else {
+                char buf[1024];
+                snprintf(buf, 1024, "$%s", key);
+                rl_completion_append_character= ' ';
+                return strdup(buf);
+            }
         }
     }
 
@@ -1385,10 +1397,9 @@ char** readline_on_complete(const char* text, int start, int end)
         }
         // リファレンス
         else if(*p == '$') {
+            string_push_back2(buf, *p);
             p++;
             ref = TRUE;
-
-            string_put(buf, "");
         }
         else if(*p == '~') {
             p++;
@@ -1409,7 +1420,20 @@ char** readline_on_complete(const char* text, int start, int end)
         else if(*p == '-' && *(p+1) == '>') {
             p+=2;
             if(program) { 
-                sObject* object = saphire_get_object(string_c_str(buf));
+                sObject* object;
+                if(string_c_str(buf)[0] == '$') {
+                    sRef* ref = saphire_get_ref(string_c_str(buf) + 1);
+
+                    if(ref && ref->mKind == kMCObject) {
+                        object = ref->mMem;
+                    }
+                    else {
+                        object = NULL;
+                    }
+                }
+                else {
+                    object = saphire_get_object(string_c_str(buf));
+                }
 
                 if(object) {
                     gMethodCompletions = saphire_methods_names(object);
@@ -1640,17 +1664,17 @@ char** readline_on_complete(const char* text, int start, int end)
         rl_completion_append_character= 0;
         return rl_completion_matches(text, rl_username_completion_function);
     }
-    else if(program) {
-        rl_completion_append_character= ' ';
-        return rl_completion_matches(text, readline_program_completion);
+    else if(ref) {
+        gDerefCompletionProgram = program;
+        return rl_completion_matches(text, readline_deref_completion);
     }
     else if(method) {
         rl_completion_append_character= ' ';
         return rl_completion_matches(text, readline_method_completion);
     }
-    else if(ref) {
+    else if(program) {
         rl_completion_append_character= ' ';
-        return rl_completion_matches(text, readline_deref_completion);
+        return rl_completion_matches(text, readline_program_completion);
     }
 #if defined(HAVE_MIGEMO_H)
     else {
