@@ -84,6 +84,25 @@ sObject* sObject_new(char* name, sClass* klass, sObject* parent);
 sObject* saphire_get_object(char* name);
     // 引数の名前のオブジェクトを返す
 
+/// メモリチェッカー
+void memchecker_init();
+enum eMemCheckerKind { kMCNothing, kMCRef, kMCArray, kMCObject, kMCHash, kMCVar, kMCGlobal, kMCFunction, kMCClass };
+
+void* memchecker_GC_malloc(int size, enum eMemCheckerKind obj_kind);
+    // メモリチェッカーを使ったGCのメモリ領域確保
+int memchecker_is_enable_mem(void* obj);
+    // オブジェクトの種類を返す 0:無し 1:string_obj*
+
+typedef struct {
+    void* mMem;
+    enum eMemCheckerKind mKind;
+} sRef;
+
+sRef* sRef_new(void* mem, enum eMemCheckerKind kind);
+
+sRef* saphire_get_ref(char* name);
+    // 引数の名前のリファレンスを返す
+
 vector_obj* saphire_methods_names(sObject* object);
     // 引数のオブジェクトのメソッドの一覧を返す
 
