@@ -1,5 +1,11 @@
 #include "config.h"
+#if defined(HAVE_GC_H)
+#include <gc.h>
+#elif defined(HAVE_GC_GC_H)
+#include <gc/gc.h>
+#endif
 #include "saphire_debug.h"
+#include "saphire_hash.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -202,3 +208,4 @@ void CheckMemLeak_Free(void* memory, const char* file_name, int line, const char
 }
 
 #endif
+
