@@ -2540,7 +2540,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "3.4.5", 1);
+    setenv("SAPHIRE_VERSION", "3.4.7", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
@@ -3930,6 +3930,10 @@ sObject* saphire_get_object(char* name)
     return hash_item(gObjects, name);
 }
 
+sRef* saphire_get_ref(char* name)
+{
+    return hash_item(gRefs, name);
+}
 
 string_obj* sVar_new(char* str)
 {
